@@ -188,11 +188,12 @@ DEFAULT_CONFIG = {
         'extension_types': {
             'txt': 'text/plain',
             'html': 'text/html',
-            'json': 'application/json'},
+            'json': 'application/vnd.tiddlyweb+json'},
         'serializers': {
             'text/html': ['html', 'text/html; charset=UTF-8'],
             'text/plain': ['text', 'text/plain; charset=UTF-8'],
-            'application/json': ['json', 'application/json']},
+            'application/json': ['json', 'application/json'],
+            'application/vnd.tiddlyweb+json': ['json', 'application/json']},
         'default_serializer': 'text/html',
         'extractors': [
             'http_basic',
