@@ -61,15 +61,12 @@ of any benefit. In some stores (for example caching stores) traversing
 the tiddlers is faster than using an index.
 """
 
-try:
-    from urlparse import parse_qs
-except ImportError:
-    from cgi import parse_qs
-
 from tiddlyweb.filters.select import select_parse
 from tiddlyweb.filters.sort import sort_parse
 from tiddlyweb.filters.limit import limit_parse
 
+from tiddlyweb.fixups import parse_qs, unicode
+
 
 class FilterError(Exception):
     """
@@ -113,8 +110,13 @@ def parse_for_filters(query_string, environ=None):
     for string in strings:
         query = parse_qs(string)
         try:
-            key, value = query.items()[0]
+            key, value = list(query.items())[0]
 
+            # We need to adapt to different types from the
+            # query_string. It changes per Python version,
+            # and per store (because of Python version).
+            # Sometimes we will already be unicode here,
+            # sometimes not.
             try:
                 argument = unicode(value[0], 'UTF-8')
             except TypeError:
@@ -147,9 +149,9 @@ def recursive_filter(filters, entities, indexable=False):
             environ = {}
         try:
             entities = active_filter(entities, indexable, environ)
-        except FilterIndexRefused, exc:
+        except FilterIndexRefused as exc:
             entities = active_filter(entities, False, environ)
-        except (ValueError, AttributeError), exc:
+        except (ValueError, AttributeError) as exc:
             raise FilterError('malformed filter: %s' % exc)
         indexable = False
     return entities
