@@ -29,9 +29,8 @@ class Extractor(ExtractorInterface):
             return False
         if user_info.startswith('Basic'):
             user_info = user_info.strip().split(' ')[1]
-            candidate_username, password = b64decode(user_info).split(':')
-            candidate_username = candidate_username.decode('UTF-8')
-            password = password.decode('UTF-8')
+            decoded = b64decode(user_info.encode('utf-8')).decode('utf-8')
+            candidate_username, password = decoded.split(':')
             user = self.load_user(environ, candidate_username)
             if user.check_password(password):
                 return {"name": user.usersign, "roles": user.list_roles()}
