@@ -7,7 +7,7 @@ Here because nowhere else seems right.
 from tiddlyweb.serializer import Serializer
 
 
-ROOT_PAGE = """<ul id="root" class="listing">
+ROOT_PAGE = u"""<ul id="root" class="listing">
 <li><a href="%s/recipes">recipes</a></li>
 <li><a href="%s/bags">bags</a></li>
 </ul>"""
