@@ -1,11 +1,12 @@
 """
-Wikitext renderer which does not render the wikitext
-but instead wraps it in pre tags.
+A default simple wikitext renderer which does not render the wikitext
+but instead wraps it in ``pre`` tags.
 """
 from tiddlyweb.web.util import html_encode
 
+
 def render(tiddler, environ):
     """
-    Wrap html encoded wikitext with pre tags.
+    Wrap HTML encoded wikitext with ``pre`` tags.
     """
     return '<pre>\n' + html_encode(tiddler.text) + '</pre>\n'
